@@ -20,8 +20,10 @@
 
 /*****************************************************************************
 **
-**  File:    mod_ports.c
-**  Date:    January 15, 2005
+**  File:     mod_ports.c
+**  Date:     January 15, 2005
+**  Modified: July 30, 2006
+**  Version:  0.4
 **
 **  Author:  Brian Wotring
 **  Purpose: platform specific methods for detecting open network ports.
@@ -43,6 +45,7 @@ static const char *MODULE_NAME = "mod_ports";
 static const char *PARAM_IGNORETCP = "ignoretcp";
 static const char *PARAM_IGNOREUDP = "ignoreudp";
 static const char *PARAM_IGNOREINODE = "ignoreinode";
+static const char *PARAM_IGNOREUID = "ignoreuid";
 
 #ifdef WIN32
 
@@ -497,16 +500,34 @@ void process_proc_file( SCANNER *scanner, const char *filename )
 
         if ( inode_is_filtered( scanner ) )
         {
-            osi_snprintf( record.data, sizeof( record.data ),
-                          "%s:%d;local=%s;remote=%s;uid=%d",
-                          protocol, port,local_addr,remote_addr,uid);
+            if ( uid_is_filtered( scanner ) )
+            {
+                osi_snprintf( record.data, sizeof( record.data ),
+                              "%s:%d;local=%s;remote=%s",
+                              protocol, port,local_addr,remote_addr);
+	    }
+	    else
+	    {
+                osi_snprintf( record.data, sizeof( record.data ),
+                              "%s:%d;local=%s;remote=%s;uid=%d;",
+                              protocol, port,local_addr,remote_addr,uid);
+            }
         }
 
         else
         {
-            osi_snprintf( record.data, sizeof( record.data ),
-                          "%s:%d;local=%s;remote=%s;uid=%d;inode=%ld",
-                          protocol, port,local_addr,remote_addr,uid,inode );
+            if ( uid_is_filtered( scanner ) )
+            {
+                osi_snprintf( record.data, sizeof( record.data ),
+                              "%s:%d;local=%s;remote=%s;inode=%ld",
+                              protocol, port,local_addr,remote_addr,inode );
+            }
+	    else
+            {
+                osi_snprintf( record.data, sizeof( record.data ),
+                              "%s:%d;local=%s;remote=%s;uid=%d;inode=%ld",
+                              protocol, port,local_addr,remote_addr,uid,inode );
+            }
         }
 
         send_scan_data( scanner, (SCAN_RECORD *)&record );
@@ -527,6 +548,35 @@ void process_ports_linux( SCANNER *scanner )
 
 #endif
 
+osi_bool uid_is_filtered( SCANNER *scanner )
+{
+    node *n;
+    module *m;
+
+    m = get_module_with_name( scanner->config, "mod_ports" );
+
+    if ( !m )
+    {
+        return FALSE;
+    }
+
+    n = list_get_first_node( m->params );
+
+    while ( n )
+    {
+        param *p = (param *)n->data;
+
+        if ( p && strcmp( p->name, PARAM_IGNOREUID ) == 0 )
+        {
+            return TRUE;
+        }
+
+        n = n->next;
+    }
+
+    return FALSE;
+}
+
 osi_bool inode_is_filtered( SCANNER *scanner )
 {
     node *n;
